@@ -10,7 +10,6 @@
 #### density estimation with directional data
 #### Electronic Journal of Statistics
 ################################
-
 vm.kde <- function(u, h = NULL, thumb = "none", rads = TRUE) {
   ## u is the data
   ## h is the bandwidth you want
@@ -28,12 +27,10 @@ vm.kde <- function(u, h = NULL, thumb = "none", rads = TRUE) {
 
     if (thumb == "tay") {
       k <- circ.summary(u, rads = TRUE, plot = FALSE)$kappa
-      h <- ( 4 * pi^0.5 * besselI(k, 0)^2 / (3 * n * k^2 *
-      besselI(2 * k, 2)) )^0.2
+      h <- ( 4 * pi^0.5 * besselI(k, 0)^2 / (3 * n * k^2 * besselI(2 * k, 2)) )^0.2
     } else if (thumb == "rot") {
       k <- circ.summary(u, rads = TRUE, plot = FALSE)$kappa
-      h <- ( 4 * pi^0.5 * besselI(k, 0)^2 / ( k * n * ( 2 * besselI(2 * k, 1) +
-      3 * k * besselI(2 * k, 2)) ) )^0.2
+      h <- ( 4 * pi^0.5 * besselI(k, 0)^2 / ( k * n * ( 2 * besselI(2 * k, 1) + 3 * k * besselI(2 * k, 2)) ) )^0.2
     } else if (thumb == "none") {
       h <- as.numeric( vmkde.tune(u, low = 0.1, up = 1)[1] )
     }
